@@ -1,4 +1,5 @@
 import asyncio
+
 from pydantic import BaseModel
 
 
@@ -8,6 +9,8 @@ class File(BaseModel):
 
     @classmethod
     def from_path(cls, path: str):
+        if not path.startswith("/"):
+            path = f"./{path}"
         with open(path, "rb") as f:
             path = path.split("/")[-1]
             return cls(name=path, content=f.read())
@@ -32,6 +35,8 @@ class File(BaseModel):
                 return cls(name=url.split("/")[-1], content=await r.read())
 
     def save(self, path: str):
+        if not path.startswith("/"):
+            path = f"./{path}"
         with open(path, "wb") as f:
             f.write(self.content)
 
@@ -43,7 +48,9 @@ class File(BaseModel):
             from PIL import Image  # type: ignore
         except ImportError:
             print(
-                "Please install it with `pip install codeinterpreterapi[image_support]` to display images."
+                "Please install it with "
+                "`pip install 'codeinterpreterapi[image_support]'`"
+                " to display images."
             )
             exit(1)
 
@@ -53,32 +60,27 @@ class File(BaseModel):
         img = Image.open(img_io)
 
         # Convert image to RGB if it's not
-        if img.mode not in ('RGB', 'L'):  # L is for greyscale images
-            img = img.convert('RGB')
+        if img.mode not in ("RGB", "L"):  # L is for greyscale images
+            img = img.convert("RGB")
 
         return img
 
     def show_image(self):
         img = self.get_image()
-
         # Display the image
         try:
             # Try to get the IPython shell if available.
             shell = get_ipython().__class__.__name__  # type: ignore
+            # If the shell is in a Jupyter notebook or similar.
+            if shell == "ZMQInteractiveShell" or shell == "Shell":
+                from IPython.display import display  # type: ignore
 
-            # If the shell is ZMQInteractiveShell, it means we're in a Jupyter notebook or similar.
-            if shell == 'ZMQInteractiveShell':
-                from IPython.display import display
                 display(img)
             else:
-                # We're not in a Jupyter notebook.
                 img.show()
         except NameError:
-            # We're probably not in an IPython environment, use PIL's show.
             img.show()
 
-
-
     def __str__(self):
         return self.name
 
